.. pyqtribbon documentation master file, created by
   sphinx-quickstart on Fri Jul 22 18:22:21 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PyQtRibbon's documentation!
======================================

Ribbon Bar for PyQt or PySide applications.

- GitHub Repository: `github.com/haiiliin/pyqtribbon <https://github.com/haiiliin/pyqtribbon>`_.
- PyPI: `pypi.org/project/pyqtribbon <https://pypi.org/project/pyqtribbon/>`_.
- Documentation: `pyqtribbon.haiiliin.com/en/stable <https://pyqtribbon.haiiliin.com/en/stable/>`_.
- Read the Docs: `readthedocs.org/projects/pyqtribbon <https://readthedocs.org/projects/pyqribbon/>`_.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting-started
   ribbon
   user
   apidoc

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
